# Aufmerksamkeit bitte!

Eine Warnung während der Erstellung eines neuen Items wurde ausgelöst.

- Dies könnte bedeuten, dass Sie ein Plug-in gebrauchen, welches für eine ältere Version von OpenSesame geschrieben wurde.
- Warnungen können Fehlerberichte hervorrufen ("Oops, ich hab es wieder getan..."); Sie können diese ausschalten in dem Sie die Erweiterung `bug_report` deaktivieren.
- Detaillierte Informationen bezüglich der Warnung wurde in das debug-Fenster geschrieben.
